-- Version  : $Id: sesam_db_pg.sql,v 1.82 2008/09/03 09:46:26 sesam Exp $
--
-- Title    : Database for SEP sesam
-- File     : sesam_db_pg.sql
-- Author   : P.Schlegel / E.Einwanger  SEP AG D83629 Weyarn
-- Date     : 2007-05-01
-- 
--
-- ########## DROP TABLES ########################

-- ----------------------------------------------------------------------------
-- Tables without active & passive references
-- ----------------------------------------------------------------------------

drop table accounts;
drop table cal_sheets;
drop table defaults;
drop table sessions;
drop table preferences;

-- ----------------------------------------------------------------------------
-- Tables with only active references ( they refer to another table )
-- ----------------------------------------------------------------------------

drop table terms;
drop table capacities;
drop table drive_vendors;
drop table syntaxes;   			
drop table loader_contents;
drop table restore_users;
drop table result_lbls;                 
drop table task_group_relations;        
drop table servers;
drop table user_scheds;

-- ----------------------------------------------------------------------------
-- Tables with active and passive references
-- the sequence of drops MUST be kept due to inner relations
-- ----------------------------------------------------------------------------

drop table task_events;
drop table newday_events;
drop table mediapools_events;
drop table restore_events;
drop table command_events;
drop table tasks;
drop table mediapool_relations;
drop table media;
drop table media_pools;
drop table restore_tasks;
drop table results;
drop table task_sources;        
drop table hw_drives;
drop table hw_loaders;
drop table interfaces;
drop table clients;
drop table locations;

-- ----------------------------------------------------------------------------
-- Tables with only passive references ( they are referred from other tables )
-- ----------------------------------------------------------------------------

drop table commands;
drop table schedules;
drop table drive_types;
drop table media_types;
drop table mediapool_locations;
drop table oper_systems;
drop table drive_groups;
drop table restore_results;
drop table task_groups;
drop table task_types;
drop table params_fix;


-- ########## CREATE TABLES ########################

-- ----------------------------------------------------------------------------
-- Tables with only passive references ( they are referred from other tables )
-- ----------------------------------------------------------------------------


CREATE TABLE drive_types (
	drive_typ       VARCHAR(15) NOT NULL PRIMARY KEY,
	generic_typ     VARCHAR(10) NOT NULL 
);

CREATE TABLE media_types (
	media_typ       VARCHAR(20) NOT NULL PRIMARY KEY
);

CREATE TABLE oper_systems (
        os              VARCHAR(20) NOT NULL PRIMARY KEY,
        platform        VARCHAR(20) NOT NULL
); 

CREATE TABLE drive_groups (
	grp_id          INTEGER NOT NULL PRIMARY KEY,
	grp_name        VARCHAR(50),
	sms_flag        VARCHAR(1),
        restore_drive   INTEGER,
	text            VARCHAR(100),
	default_i_name	VARCHAR(64)
);

CREATE TABLE restore_results (
        restore_id      VARCHAR(21) NOT NULL PRIMARY KEY,
        start_tim       VARCHAR(21) NOT NULL,
	r_task		VARCHAR(49) NOT NULL,
        saveset         VARCHAR(32) NOT NULL,
        task            VARCHAR(32) NOT NULL,
        datum           VARCHAR(21) NOT NULL,
        cnt             INTEGER NOT NULL,
        rest_typ        VARCHAR(2) NOT NULL,
        genmode         VARCHAR(2),
        listmode        VARCHAR(32),
        tree_typ        VARCHAR(2) NOT NULL,
        mode            VARCHAR(2) NOT NULL,
        recover         VARCHAR(64),
        onlinemode      VARCHAR(64),
        client_id       INTEGER NOT NULL,
        client          VARCHAR(64) NOT NULL,
        target          VARCHAR(1024) NOT NULL,
        user_name       VARCHAR(255) NOT NULL,
	subtask_flag	CHAR(1),
	parent_task	CHAR(49),
        location        VARCHAR(50),
        drive_num       INTEGER,
        i_name          VARCHAR(64),
        filter          VARCHAR(255),
        reloc_source    VARCHAR(1024),
        state           VARCHAR(1) NOT NULL,
        stop_tim        VARCHAR(21),
        size            BIGINT,
        options         VARCHAR(255),
	throughput      VARCHAR(64),
        msg             VARCHAR(255),
	saveset_exist   VARCHAR(1)
);

CREATE TABLE task_groups (
        grp_name        VARCHAR(50) NOT NULL PRIMARY KEY,
        text            VARCHAR(100),
        results_sts     VARCHAR(1),
        prepost         VARCHAR(16),
        prepost_switch  VARCHAR(1)	
);

CREATE TABLE task_types (
        backup_type     VARCHAR(32) NOT NULL PRIMARY KEY,
        backup_cmd      VARCHAR(20),
        backup_options  VARCHAR(128),
        prepost         VARCHAR(16),
        prepost_cmd     VARCHAR(20),
        restore_cmd     VARCHAR(20),
        restore_options VARCHAR(128),
        r_prepost       VARCHAR(16),
        r_prepost_cmd   VARCHAR(20),
        source_prefix   VARCHAR(20),
        platform        VARCHAR(20),
        flags           VARCHAR(32),
        protection      VARCHAR(4),
        komment         VARCHAR(40),
        interpreter     VARCHAR(16)
);

CREATE TABLE params_fix (
	kunde           VARCHAR(50) NOT NULL PRIMARY KEY,
	rest_eol        INTEGER NOT NULL,
	min_free        INTEGER NOT NULL,
        typ             VARCHAR(20) NOT NULL,
        version         VARCHAR(32) NOT NULL,
        inst_date       VARCHAR(21) NOT NULL,
        inst_cryp       VARCHAR(21),
        update_date     VARCHAR(21) NOT NULL,
        val1            VARCHAR(128),
        val2            VARCHAR(128),
        val3            VARCHAR(128),
        val4            VARCHAR(128),
        serialnumber    VARCHAR(128),
	sts             VARCHAR(255),
	msg             VARCHAR(255)
);

CREATE TABLE mediapool_locations (
    name                VARCHAR(32) NOT NULL PRIMARY KEY,
    path                VARCHAR(1024),
    capacity            integer,
    komment             VARCHAR(80),
    load_cmd            VARCHAR(255),
    unload_cmd          VARCHAR(255),
    access_mode         VARCHAR(255),
    status              VARCHAR(255),
    device_path         VARCHAR(255)
);

CREATE TABLE commands (
        name           VARCHAR(50) NOT NULL PRIMARY KEY,
        owner          VARCHAR(30) NOT NULL,
        type           VARCHAR(1) NOT NULL,
        host           VARCHAR(64) NOT NULL,
        user_name      VARCHAR(32) NOT NULL,
        command        VARCHAR(255) NOT NULL
);

-- ----------------------------------------------------------------------------
-- Tables with active and passive references
-- the sequence of CREATE MUST be kept due to inner relations
-- ----------------------------------------------------------------------------

CREATE TABLE schedules (
	name            VARCHAR(30) NOT NULL PRIMARY KEY,
	cyc_flag        VARCHAR(1) NOT NULL,
	abs_flag        VARCHAR(1) NOT NULL,
	p_count         INTEGER,
	p_base          VARCHAR(3),
	mo              VARCHAR(1),
	tu              VARCHAR(1),
	we              VARCHAR(1),
	th              VARCHAR(1),
	fr              VARCHAR(1),
	sa              VARCHAR(1),
	su              VARCHAR(1),
	day_of_mth      VARCHAR(2),
	mth_of_yea      VARCHAR(2),
	wk_of_mth       VARCHAR(2),
	day_of_wk       VARCHAR(10),
	start_date      VARCHAR(21),
	end_date        VARCHAR(21),
	exec            VARCHAR(1),
	start_time      VARCHAR(5),
	duration        VARCHAR(5),
	day_offset      INTEGER,
        sepcomment      VARCHAR(64),
        komment         VARCHAR(64)
);

CREATE TABLE task_sources (
        task   	        VARCHAR(32)  NOT NULL,
        version_id      INTEGER      NOT NULL,
        source          VARCHAR(255) NOT NULL,
        timestamp       VARCHAR(21),
        user_name       VARCHAR(255),
        PRIMARY KEY (task,version_id)
);

CREATE TABLE results (
	saveset          VARCHAR(32) NOT NULL PRIMARY KEY,
        task             VARCHAR(32) NOT NULL,
	datum            VARCHAR(21) NOT NULL,
        cnt              INTEGER NOT NULL ,
	fdi_typ          VARCHAR(2),
	lbl_cnt          INTEGER,
	drive_num        INTEGER,
	client_id        INTEGER,
	client           VARCHAR(64),
	location         VARCHAR(50),
	source           VARCHAR(1024),
        version_id       INTEGER,
	exclude          VARCHAR(1024),
        priority         INTEGER,
	start_tim        VARCHAR(21),
	stop_tim         VARCHAR(21),
        session_id       VARCHAR(32),
	state            VARCHAR(1),
	blocks           BIGINT,
	msg              VARCHAR(254),
        sms_flag         VARCHAR(1),
        i_name           VARCHAR(64),
	sbc_start        VARCHAR(21),
	saveset_exist    VARCHAR(2),
        media_pool       VARCHAR(16),
        backup_cmd       VARCHAR(20),
        backup_type      VARCHAR(32),
        interpreter      VARCHAR(32),
        restore_options  VARCHAR(128),
        bsr_flag         VARCHAR(1),
        compress_flag    VARCHAR(1),
        crypt_flag       VARCHAR(1),
        crypt_key        VARCHAR(128),
	original_saveset VARCHAR(64),
	throughput       VARCHAR(64),
        processed        INTEGER,
        notprocessed     INTEGER, 
        user_comment     VARCHAR(256)
);

CREATE TABLE restore_tasks (
	r_task		VARCHAR(49) NOT NULL PRIMARY KEY,
        saveset         VARCHAR(32) NOT NULL,
        task            VARCHAR(32) NOT NULL,
        datum           VARCHAR(21) NOT NULL,
        cnt             INTEGER NOT NULL,
        rest_typ        VARCHAR(2) NOT NULL,
        genmode         VARCHAR(2),
        listmode        VARCHAR(32),
        tree_typ        VARCHAR(2) NOT NULL,
        mode            VARCHAR(2) NOT NULL,
        overwrite       VARCHAR(8),
        original        VARCHAR(2),
        recover         VARCHAR(64),
        onlinemode      VARCHAR(64),
        client_id       INTEGER NOT NULL,
        client          VARCHAR(64) NOT NULL,
        target          VARCHAR(1024) NOT NULL,
        user_name       VARCHAR(255) NOT NULL,
	subtask_flag	VARCHAR(1),
	parent_task	VARCHAR(49),
        location        VARCHAR(50),
        drive_num       INTEGER,
        i_name          VARCHAR(64),
        filter          VARCHAR(255),
        reloc_source    VARCHAR(1024),
        r_prepost       VARCHAR(16),
	make_stamp	VARCHAR(21) NOT NULL,
        eol             INTEGER,
        restore_cmd     VARCHAR(64),
        options         VARCHAR(128),
	komment		VARCHAR(255)
);

CREATE TABLE locations (
        id              INTEGER NOT NULL PRIMARY KEY,
	name            VARCHAR(50),
	parent          INTEGER references locations (id),
	describe        VARCHAR(128),
	contact         VARCHAR(128),
	komment         VARCHAR(128)
);

CREATE TABLE clients (
	client_id       INTEGER NOT NULL PRIMARY KEY,
        name            VARCHAR(64) NOT NULL,
	location        INTEGER references locations (id),
	os              VARCHAR(20) NOT NULL references oper_systems (os) DEFERRABLE INITIALLY DEFERRED,
	net_prot        VARCHAR(10) NOT NULL ,
	accessmode      VARCHAR(10),
	komment         VARCHAR(255),
	user_comment    VARCHAR(255),
   	permit          VARCHAR(1),
        user_name       VARCHAR(255),
        password        VARCHAR(255),
	access_options  VARCHAR(255),
	stpd_options    VARCHAR(32),
	stpd_port       VARCHAR(32),
        sbc_version     VARCHAR(20),
        data_mover      VARCHAR(64)
);

CREATE TABLE hw_loaders (
	loader_num      INTEGER NOT NULL PRIMARY KEY,
	device          VARCHAR(254) NOT NULL,
	client_id       INTEGER NOT NULL references clients (client_id) DEFERRABLE INITIALLY DEFERRED,
	name            VARCHAR(32),
	typ             VARCHAR(32) NOT NULL,
	ctrl            VARCHAR(10) NOT NULL,
	slots           INTEGER NOT NULL,
        drives          INTEGER,
        ports           INTEGER,
        transport       INTEGER,
        first_slot      INTEGER,
        last_slot       INTEGER,
        autounload      VARCHAR(1),
        barcode         VARCHAR(1)
);

CREATE TABLE hw_drives (
	drive_num       INTEGER NOT NULL PRIMARY KEY,
	device          VARCHAR(254) NOT NULL ,
	client_id       INTEGER NOT NULL references clients (client_id) DEFERRABLE INITIALLY DEFERRED,
	typ             VARCHAR(15) NOT NULL references drive_types (drive_typ) DEFERRABLE INITIALLY DEFERRED,
        name            VARCHAR(32),
	loader_num      INTEGER references hw_loaders (loader_num) DEFERRABLE INITIALLY DEFERRED,
	kompress        VARCHAR(1),
	sts             VARCHAR(132),
	msg             VARCHAR(132),
	occupy          VARCHAR(20),
	done            INTEGER,
	run             INTEGER,
	waiting         INTEGER,
       	throughput      VARCHAR(32),
        grp_id          INTEGER references drive_groups (grp_id) DEFERRABLE INITIALLY DEFERRED,
        sms_cnts        INTEGER,
       	label           VARCHAR(30),
        timeout         INTEGER,
        media_timeout   INTEGER,
        clean_bit       VARCHAR(1),
        loader_drive    INTEGER,
        path            VARCHAR(132),
        block_size      INTEGER,
        sms_nr          INTEGER,
        segment_size    INTEGER
);


CREATE TABLE media_pools (
        name             VARCHAR(16) NOT NULL PRIMARY KEY,
        pool_id          INTEGER NOT NULL,
        descript         VARCHAR(80),
        drive_grp        INTEGER NOT NULL references drive_groups (grp_id) DEFERRABLE INITIALLY DEFERRED,
        media_strg       VARCHAR(64) NOT NULL,
        media_chg        VARCHAR(8) NOT NULL,
        disk_capac       VARCHAR(16),
        disk_dir         VARCHAR(254),
        eol              INTEGER,
        accept_empty     VARCHAR(2),
        accept_eol       VARCHAR(2),
        accept_spare     VARCHAR(2),
        use_storagepools VARCHAR(2)

);

CREATE TABLE mediapool_relations (
    mediapool           VARCHAR(16) references media_pools (name) DEFERRABLE INITIALLY DEFERRED,
    mediapool_location  VARCHAR(32) references mediapool_locations (name) DEFERRABLE INITIALLY DEFERRED,
    priority            INTEGER,
    komment             VARCHAR(80)
);


CREATE TABLE interfaces (
	client_id       INTEGER  NOT NULL references clients (client_id) DEFERRABLE INITIALLY DEFERRED,
        i_name          VARCHAR(64) NOT NULL UNIQUE,
        PRIMARY KEY (client_id,i_name)
);


-- task_events.object references tasks.task or task_groups.grp_name

CREATE TABLE task_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          VARCHAR(50) NOT NULL,
        schedule        VARCHAR(30), 
        grp_flag        VARCHAR(1) NOT NULL,
        priority        INTEGER NOT NULL,
        suppress        VARCHAR(1),
        owner           VARCHAR(30) NOT NULL,
        fdi_typ         VARCHAR(2) NOT NULL,
        media_pool      VARCHAR(16) NOT NULL,
        label           VARCHAR(30),
        drive_num       INTEGER references hw_drives (drive_num) DEFERRABLE INITIALLY DEFERRED,
	i_name		VARCHAR(64) references interfaces (i_name) DEFERRABLE INITIALLY DEFERRED,
        data_mover      VARCHAR(64),
        max_since_full  VARCHAR(21)
);

CREATE TABLE newday_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          VARCHAR(50) NOT NULL references params_fix (kunde) DEFERRABLE INITIALLY DEFERRED,
        schedule        VARCHAR(30),
        priority        INTEGER NOT NULL,
        suppress        VARCHAR(1),
        owner           VARCHAR(30) NOT NULL
);

CREATE TABLE mediapools_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          VARCHAR(16) NOT NULL references media_pools (name) DEFERRABLE INITIALLY DEFERRED,
        drive           VARCHAR(16),
        schedule        VARCHAR(30), 
        priority        INTEGER NOT NULL,
        suppress        VARCHAR(1),
        owner           VARCHAR(30) NOT NULL,
        grp_flag        VARCHAR(1) NOT NULL,
        m_count         INTEGER,
        label           VARCHAR(30),
        emergency       VARCHAR(30)
);

CREATE TABLE restore_events (
        id               INTEGER NOT NULL PRIMARY KEY,
	object           VARCHAR(49) NOT NULL references restore_tasks (r_task) DEFERRABLE INITIALLY DEFERRED,
        schedule         VARCHAR(30),
        priority         INTEGER NOT NULL,
        suppress         VARCHAR(1),
        owner            VARCHAR(30) NOT NULL,
        drive_num        INTEGER,
        i_name           VARCHAR(64),
        listmode         VARCHAR(32),
        absolute_flag    VARCHAR(1),
        saveset_start    INTEGER,
        saveset_end      INTEGER,
        min_max          VARCHAR(21),
        date_start       VARCHAR(21),
        date_end         VARCHAR(21),
        state            VARCHAR(12),
        cfdi_type        VARCHAR(12),
        media_pools      VARCHAR(255),
        media_tolerance  VARCHAR(21),
        media_preference VARCHAR(21),
        data_mover       VARCHAR(64),
        use_saveset      VARCHAR(32),
        restore_cmd      VARCHAR(64),
        options          VARCHAR(128)

);

CREATE TABLE command_events (
        id               INTEGER NOT NULL PRIMARY KEY,
        object           VARCHAR(50) NOT NULL,
        schedule         VARCHAR(30),
        priority         INTEGER NOT NULL,
        suppress         VARCHAR(1),
        owner            VARCHAR(30) NOT NULL,
        type             VARCHAR(1) NOT NULL,
        host             VARCHAR(64) NOT NULL,
        user_name        VARCHAR(32) NOT NULL,
        command          VARCHAR(255) NOT NULL
);

CREATE TABLE media (
    	label           VARCHAR(30) NOT NULL PRIMARY KEY,
    	barcode         VARCHAR(30) ,
        pool            VARCHAR(16) NOT NULL references media_pools (name) DEFERRABLE INITIALLY DEFERRED,
        id              INTEGER NOT NULL ,
	sperrkz         VARCHAR(1) NOT NULL ,
	sichtag         VARCHAR(21) NOT NULL ,
	eol             VARCHAR(21),
	drive_num       INTEGER,
        init_drive      INTEGER,
	folgekass       INTEGER,
	kasstyp         VARCHAR(20) NOT NULL references media_types (media_typ) DEFERRABLE INITIALLY DEFERRED,
	lader           INTEGER,
	slot            INTEGER,
	gefuellt        BIGINT,
	eom_state       VARCHAR(1),
	first_init      VARCHAR(21),
        close_tape      VARCHAR(1),
	init_flag       VARCHAR(1),
	error           INTEGER,
	error_delt      INTEGER,
	use_count       INTEGER,
	location        VARCHAR(32),
	duplflag        VARCHAR(1),
	kommentar       VARCHAR(254),
	user_comment    VARCHAR(254)
);

CREATE TABLE tasks (
	task   	        VARCHAR(32) NOT NULL PRIMARY KEY,
        backup_type     VARCHAR(32) references task_types (backup_type) DEFERRABLE INITIALLY DEFERRED,
	client_id       INTEGER NOT NULL references clients (client_id) DEFERRABLE INITIALLY DEFERRED,
	source          VARCHAR(1024),
	exclude         VARCHAR(1024),
	komment         VARCHAR(255),		
	results_sts     VARCHAR(1),
        backup_cmd      VARCHAR(64),
	backup_options  VARCHAR(255),
	restore_options VARCHAR(255),
	prepost         VARCHAR(16),
        r_prepost       VARCHAR(16),
        nfs_mount       VARCHAR(1),
        filesystem      VARCHAR(1),
        bsr_flag        VARCHAR(1),
        compress_flag   VARCHAR(1),
        crypt_flag      VARCHAR(1),
        crypt_key       VARCHAR(128)
);

-- ----------------------------------------------------------------------------
-- Tables with only active references ( they refer to another table )
-- ----------------------------------------------------------------------------

CREATE TABLE terms (
       id               INTEGER NOT NULL PRIMARY KEY,
       type             VARCHAR(1) NOT NULL,
       schedule         VARCHAR(30) NOT NULL references schedules (name) DEFERRABLE INITIALLY DEFERRED,
       next_exec        VARCHAR(21),
       next_end         VARCHAR(21)
);

CREATE TABLE capacities (
	drive_typ       VARCHAR(15) NOT NULL references drive_types (drive_typ) DEFERRABLE INITIALLY DEFERRED,
	media_typ       VARCHAR(20) NOT NULL references media_types (media_typ) DEFERRABLE INITIALLY DEFERRED,
	kapaz_num       INTEGER NOT NULL,
        protection      VARCHAR(4) NOT NULL,
        PRIMARY KEY (drive_typ,media_typ)
);

CREATE TABLE drive_vendors (
	drive_typ       VARCHAR(15) NOT NULL references drive_types (drive_typ) DEFERRABLE INITIALLY DEFERRED,
	vendor_typ      VARCHAR(16) NOT NULL,
        protection      VARCHAR(4) NOT NULL,
	PRIMARY KEY (drive_typ,vendor_typ)
);

CREATE TABLE syntaxes (
	os              VARCHAR(20) NOT NULL references oper_systems (os) DEFERRABLE INITIALLY DEFERRED,
	command         VARCHAR(20) NOT NULL,
	syntax          VARCHAR(50) NOT NULL,
        PRIMARY KEY (os,command)
);

CREATE TABLE task_group_relations (
        grp_name        VARCHAR(50) NOT NULL references task_groups (grp_name) DEFERRABLE INITIALLY DEFERRED,
	task   	        VARCHAR(32) NOT NULL references tasks (task) DEFERRABLE INITIALLY DEFERRED,
	task_order      INTEGER,
        PRIMARY KEY (grp_name,task)
);

CREATE TABLE result_lbls (
        saveset         VARCHAR(32) NOT NULL references results (saveset) DEFERRABLE INITIALLY DEFERRED,
	num             INTEGER NOT NULL,
	label           VARCHAR(30) NOT NULL,
        segment         VARCHAR(20) NOT NULL,
        PRIMARY KEY (saveset,num)
);

CREATE TABLE restore_users (
	name            VARCHAR(255) NOT NULL,
	task            VARCHAR(32) NOT NULL references tasks (task) DEFERRABLE INITIALLY DEFERRED,
	path            VARCHAR(132) NOT NULL,
	komment         VARCHAR(100),
        PRIMARY KEY (name,task,path)
);

CREATE TABLE loader_contents (
        loader          INTEGER	NOT NULL references hw_loaders (loader_num) DEFERRABLE INITIALLY DEFERRED,
        object          VARCHAR(10) NOT NULL,
        number          INTEGER	NOT NULL,
        lbl             VARCHAR(30),
	barcode         VARCHAR(30),
        check_lbl       VARCHAR(1),
        checkedlbl      VARCHAR(30),
        from_object     VARCHAR(10),
        from_number     INTEGER,
        to_object       VARCHAR(10),
        to_number       INTEGER,	
        PRIMARY KEY (loader,object,number)
);

CREATE TABLE servers (
        name            VARCHAR(64) NOT NULL PRIMARY KEY,
	os              VARCHAR(20) NOT NULL references oper_systems (os) DEFERRABLE INITIALLY DEFERRED,
        ip_address      VARCHAR(64),
        rmi_port        INTEGER,
        ctrl_port       INTEGER,
        db_port         INTEGER,
        db_name         VARCHAR(73),
        db_alias        VARCHAR(73),
        db_type         VARCHAR(32),
        connect         VARCHAR(1),
        komment         VARCHAR(80),
        id              INTEGER
);

CREATE TABLE user_scheds (
     name            VARCHAR(30) NOT NULL references schedules (name) DEFERRABLE INITIALLY DEFERRED,
     date_name       VARCHAR(32) NOT NULL,
     date_pattern    VARCHAR(32) NOT NULL,
     next_exec       VARCHAR(32),
     notices         VARCHAR(100),
     PRIMARY KEY (name,date_name)
);

-- ----------------------------------------------------------------------------
-- Tables without active & passive references
-- ----------------------------------------------------------------------------

CREATE TABLE accounts (
        account_name       VARCHAR(64) NOT NULL PRIMARY KEY,
        kunde              VARCHAR(64),
        smtp_email_address VARCHAR(64) NOT NULL,
        smtp_server        VARCHAR(64) NOT NULL,
        mail_username      VARCHAR(64),
        mail_password      VARCHAR(128),
        mail_to            VARCHAR(128) NOT NULL,
        mail_cc            VARCHAR(128),
        mail_bcc           VARCHAR(128),
        service_location   VARCHAR(64)
);

CREATE TABLE cal_sheets (
	id		VARCHAR(30) PRIMARY KEY,
	start		VARCHAR(21),
	end_time        VARCHAR(21),
	ev_type		VARCHAR(3),
	ev_id		INTEGER,
	schedule	VARCHAR(30),
        priority        INTEGER,
	state		VARCHAR(3),
        object          VARCHAR(132),
        suppress        VARCHAR(1),
	msg		VARCHAR(132)
);

CREATE TABLE defaults (	
        key             VARCHAR(32) NOT NULL,
        user_name       VARCHAR(255) NOT NULL ,
        value           VARCHAR(255) NOT NULL,
        host            VARCHAR(255),
        protection      VARCHAR(4),
        PRIMARY KEY     (key,user_name)
);


CREATE TABLE sessions (
	session_id      VARCHAR(32) PRIMARY KEY,
	object		VARCHAR(32),
	komment		VARCHAR(80)
);


CREATE TABLE preferences (
        pref_node       VARCHAR(255)  NOT NULL,
        pref_user       VARCHAR(255)  NOT NULL,
        pref_key        VARCHAR(255)  NOT NULL,
        pref_value      VARCHAR(255)  NOT NULL,
        PRIMARY KEY     (pref_node,pref_user,pref_key)
);
